'use strict';

var fs = require('fs');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var fs__default = /*#__PURE__*/_interopDefault(fs);

function isIterable(value) {
  return Symbol.iterator in value;
}
function transformFile(fn, filename, chain) {
  const data = fs__default.default.readFileSync(filename, "utf-8");
  const source = {
    filename,
    line: 1,
    column: 1,
    offset: 0,
    data
  };
  return transformSource(fn, source, chain);
}
function transformString(fn, data, chain) {
  const source = {
    filename: "inline",
    line: 1,
    column: 1,
    offset: 0,
    data
  };
  return transformSource(fn, source, chain);
}
async function transformSource(fn, source, chain) {
  const defaultChain = (source2) => [source2];
  const context = {
    hasChain: (
      /* istanbul ignore next */
      () => true
    ),
    chain: chain ?? defaultChain
  };
  const result = await fn.call(context, source);
  if (isIterable(result)) {
    return await Promise.all(Array.from(result));
  } else {
    return [result];
  }
}

exports.transformFile = transformFile;
exports.transformSource = transformSource;
exports.transformString = transformString;
//# sourceMappingURL=test-utils.js.map
